==> karot_components-0.0.3.tar.gz: lib/button/karot_icon_button.dart <==
import 'package:flutter/material.dart';
import 'package:flutter/widgets.dart';
import 'package:karot_components/constant/button_enum.dart';
import 'package:karot_components/constant/button_style.dart';
import 'package:karot_components/constant/text_style.dart';
import 'package:karot_components/constant/theme.dart';

class KRIconButton extends StatelessWidget {
  final IconData iconData;
  final bool isDisabled;
  final String? text;
  final int? textBackgroundColor;
  final int color;
  final int? backgroundColor;
  final bool isOutline;
  final bool isCirle;
  final KRButtonSize size;
  final VoidCallback? onPress;

  const KRIconButton(
      {Key? key,
      required this.iconData,
      this.onPress,
      this.text,
      this.isDisabled = false,
      this.textBackgroundColor = KRTheme.DEFAULT_PRIMARY_COLOR,
      this.isOutline = false,
      this.isCirle = true,
      this.size = KRButtonSize.large,
      this.backgroundColor,
      required this.color})
      : super(key: key);

  @override
  Widget build(BuildContext context) {
    return TextButton(
        style: BStyle.iconButtonStyle(
            backgroundColor:
                text != null ? textBackgroundColor : backgroundColor,
            isOutline: isOutline,
            size: size,
            isCirle: isCirle),
        onPressed: isDisabled ? null : onPress,
        child: text != null
            ? Text(" $text ",
                style: TStyle.textText(
                    isBold: true,
                    color: const Color(KRTheme.DEFAULT_LIGHT_COLOR)))
            : Icon(iconData, size: size.squerySize, color: isDisabled ? const Color(KRTheme.DEFAULT_GREY_LIGHT_COLOR) : Color(color)));
  }
}

==> karot_components-0.0.5.tar.gz: lib/button/karot_icon_button.dart <==
import 'package:flutter/material.dart';
import 'package:flutter/widgets.dart';
import 'package:karot_components/constant/button_enum.dart';
import 'package:karot_components/constant/button_style.dart';
import 'package:karot_components/constant/text_style.dart';
import 'package:karot_components/constant/theme.dart';

class KRIconButton extends StatelessWidget {
  final IconData iconData;
  final bool isDisabled;
  final String? text;
  final int? textBackgroundColor;
  final int color;
  final int? backgroundColor;
  final bool isOutline;
  final bool isCirle;
  final KRButtonSize size;
  final VoidCallback? onPressed;

  const KRIconButton(
      {Key? key,
      required this.iconData,
      required this.color,
      required this.onPressed,
      this.text,
      this.isDisabled = false,
      this.textBackgroundColor = KRTheme.DEFAULT_PRIMARY_COLOR,
      this.isOutline = false,
      this.isCirle = true,
      this.size = KRButtonSize.large,
      this.backgroundColor})
      : super(key: key);

  @override
  Widget build(BuildContext context) {
    return 
  TextButton(
        style: BStyle.iconButtonStyle(
            backgroundColor:
                text != null ? textBackgroundColor : backgroundColor,
            isOutline: isOutline,
            size: size,
            isCirle: isCirle),
        onPressed: isDisabled ? null : onPressed,
        child: text != null
            ? Text(" $text ",
                style: TStyle.textText(
                    isBold: true,
                    color: const Color(KRTheme.DEFAULT_LIGHT_COLOR)))
            : Icon(iconData, size: size.squerySize, color: isDisabled ? const Color(KRTheme.DEFAULT_GREY_LIGHT_COLOR) : Color(color)));
  }
}
